@@ -515,8 +515,7 @@ create_fn_choose_mpst_cancel_multi_to_all_bundle!(
 );
 
 fn endpoint_central(s: EndpointCentral) -> Result<(), Box<dyn Error>> {
-    broadcast_cancel!(s, 10);
-    Ok(())
+    broadcast_cancel!(s, 10)
 }
 
 fn endpoint_a(s: EndpointA) -> Result<(), Box<dyn Error>> {
