@@ -3,13 +3,23 @@ use crate::role::Role;
 use crossbeam_channel::{bounded, Sender};
 
 /// Gives the order to the
-/// [`mpstthree::meshedchannels::MeshedChannels`] related to B.
+/// [`MeshedChannels`] related to B.
 ///
 /// This `struct` should only be used in the `stack` field
-/// of the [`mpstthree::meshedchannels::MeshedChannels`] related
+/// of the [`MeshedChannels`] related
 /// to B.
 ///
-/// [`mpstthree::meshedchannels::MeshedChannels`]: ../meshedchannels/struct.MeshedChannels.html
+/// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// # Example
+///
+/// ```
+/// use mpstthree::role::b::RoleB;
+/// use mpstthree::role::end::RoleEnd;
+///
+/// type NameB = RoleB<RoleEnd>;
+/// ```
+#[derive(Debug)]
 pub struct RoleB<R>
 where
     R: Role,
